django-locations
================

A small reusable locations app for Django.  Formally apart of the Hadrian project.

This supports Python 2 and 3 **only**


Installation
------------

    pip install django-locations-base


Add to installed apps.

More docs coming soon.
